class Outros(object):

    def __init__(self, outros):
        self.TituloEmissaoBoleto = None
        self.TituloCategoria = None
        self.TituloPostagemBoleto = None
        self.TituloCodEmissaoBloqueto = None
        self.TituloCodDistribuicaoBloqueto = None
        self.TituloOutrosAcrescimos = None
        self.TituloInformacoesAdicionais = None
        self.TituloInstrucoes = None
        self.TituloParcela = None
        self.TituloVariacaoCarteira = None
        self.TituloCodigoReferencia = None
        self.TituloTipoCobranca = None
